@@ -17,6 +17,7 @@ def create_all_metadata(
     source_folder,
     include_op_column=True,
     include_timestamp_column=True,
+    include_scn_column=True,
     include_derived_columns=True,
     include_objects=False,
     filter_function=None,
@@ -61,6 +62,10 @@ def create_all_metadata(
         If True, adds a column called 'extraction_timestamp'.
         This data is added by DMS if the source extra connection attribute is set.
 
+    include_scn_column (boolean):
+        If True, adds a column called 'scn'.
+        This data is added by DMS after being extracted from the source Oracle table.
+
     include_derived_columns (boolean):
         If True, adds three columns: mojap_current_record, mojap_start_datetime,
         mojap_end_datetime.
@@ -80,6 +85,7 @@ def create_all_metadata(
         source_folder,
         include_op_column,
         include_timestamp_column,
+        include_scn_column,
         include_derived_columns,
         include_objects,
     )
@@ -95,6 +101,7 @@ def create_metadata_folder(
     source_folder,
     include_op_column=True,
     include_timestamp_column=True,
+    include_scn_column=True,
     include_derived_columns=False,
     include_objects=False,
 ):
@@ -135,6 +142,10 @@ def create_metadata_folder(
         If True, adds a column called 'extraction_timestamp'.
         This data is added by DMS if the source extra connection attribute is set.
 
+    include_scn_column (boolean):
+        If True, adds a column called 'scn'.
+        This data is added by DMS after being extracted from the source Oracle table.
+
     include_derived_columns (boolean):
         If True, adds three columns: mojap_current_record, mojap_start_datetime,
         mojap_end_datetime.
@@ -166,6 +177,7 @@ def create_metadata_folder(
         location=destination,
         include_op_column=include_op_column,
         include_timestamp_column=include_timestamp_column,
+        include_scn_column=include_scn_column,
         include_derived_columns=include_derived_columns,
         include_objects=include_objects,
         connection=connection,
@@ -222,6 +234,7 @@ def create_json_for_tables(
     location="./meta_data",
     include_op_column=True,
     include_timestamp_column=True,
+    include_scn_column=True,
     include_derived_columns=False,
     include_objects=False,
     connection=None,
@@ -249,6 +262,10 @@ def create_json_for_tables(
         If True, adds a column called 'extraction_timestamp'.
         This data is added by DMS if the source extra connection attribute is set.
 
+    include_scn_column (boolean):
+        If True, adds a column called 'scn'.
+        This data is added by DMS after being extracted from the source Oracle table.
+
     include_derived_columns (boolean):
         If True, adds three columns: mojap_current_record, mojap_start_datetime,
         mojap_end_datetime.
@@ -287,6 +304,7 @@ def create_json_for_tables(
                 not_nullable.get(table.lower(), []),
                 include_op_column,
                 include_timestamp_column,
+                include_scn_column,
                 include_derived_columns,
                 include_objects,
             )
@@ -316,6 +334,7 @@ def get_table_meta(
     not_nullable: list,
     include_op_column: bool = True,
     include_timestamp_column: bool = True,
+    include_scn_column: bool = True,
     include_derived_columns: bool = False,
     include_objects: bool = False,
 ) -> list:
@@ -343,6 +362,10 @@ def get_table_meta(
         If True, adds a column called 'extraction_timestamp'
         This data is added by AWS DMS, when configured as an extra connection attribute.
 
+    include_scn_column (boolean):
+        If True, adds a column called 'scn'
+        This data is added by DMS after being extracted from the source Oracle table.
+
     include_derived_columns (boolean):
         If True, adds three columns: mojap_current_record, mojap_start_datetime,
         mojap_end_datetime.
@@ -393,6 +416,16 @@ def get_table_meta(
             }
         )
 
+    if include_scn_column:
+        columns.append(
+            {
+                "name": "scn",
+                "type": "character",
+                "description": "Oracle system change number",
+                "nullable": True,
+            }
+        )
+
     # Data types to skip. This list is specific to working with
     # Amazon Database Migration Service and an Oracle database.
     # These are the Oracle datatypes that DMS can't copy
