@@ -1,6 +1,6 @@
 from pathlib import Path
 from datetime import datetime
-from data_engineering_extract_metadata.utils import write_json, make_folder_if_new
+from data_engineering_extract_metadata.utils import write_json, prepare_folder
 
 
 def get_table_list(
@@ -129,7 +129,7 @@ def save_tables(title: str, folder: str, tables: list, blobs: list = []):
     tables (list[str]):
         List of table names
     """
-    make_folder_if_new(folder)
+    prepare_folder(folder, clear_content=False)
 
     output = {
         "tables_from": title,
