@@ -1,5 +1,6 @@
 import json
 import os
+import shutil
 
 from pathlib import Path
 
@@ -20,8 +21,14 @@ def read_json(filename, folder):
         return json.load(json_data)
 
 
-def make_folder_if_new(folder):
-    """Check if a path already exists, and make the necessary folders if it doesn't"""
+def prepare_folder(folder, clear_content=True):
+    """Check if a path already exists, and make the necessary folders if it doesn't.
+    Otherwise, delete existing files and recreate it as a fresh folder. This DOESN'T
+    carry warnings before deletion so all files will be lost! Option allows you to skip
+    deleting existing content if you wish."""
     destination = Path.cwd() / folder
     if not os.path.exists(destination):
         os.makedirs(destination)
+    elif clear_content is True:
+        shutil.rmtree(destination)
+        os.makedirs(destination)
